@@ -4,7 +4,7 @@ use Mojo::Base -base;
 use Mojo::Collection;
 use Mojo::Util 'tablify';
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 has 'sth';
 
@@ -16,7 +16,7 @@ sub new {
 
 sub DESTROY {
   my $self = shift;
-  return unless my $sth = $self->{sth};
+  return() unless my $sth = $self->{sth};
   $sth->finish unless --$sth->{private_mojo_refcount};
 }
 
